about summary refs log tree commit diff
path: root/tests/dependencies.sh
diff options
context:
space:
mode:
Diffstat (limited to 'tests/dependencies.sh')
-rw-r--r--tests/dependencies.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/dependencies.sh b/tests/dependencies.sh
index 87f0682ac438..56e1b286b6aa 100644
--- a/tests/dependencies.sh
+++ b/tests/dependencies.sh
@@ -22,8 +22,8 @@ if echo "$deps" | grep -q "dependencies-input-1"; then exit 1; fi
 # Input-2 is retained.
 input2OutPath=$(echo "$deps" | grep "dependencies-input-2")
 
-# The referers closure of input-2 should include outPath.
-$TOP/src/nix-store/nix-store -q --referers-closure "$input2OutPath" | grep "$outPath"
+# The referrers closure of input-2 should include outPath.
+$TOP/src/nix-store/nix-store -q --referrers-closure "$input2OutPath" | grep "$outPath"
 
 # Check that the derivers are set properly.
 test $($TOP/src/nix-store/nix-store -q --deriver "$outPath") = "$drvPath"